KRUTRIM PROVIDES THIS SOFTWARE DEVELOPER KIT (THE “SDK” INCLUDES SEVERAL “COMPONENTS”: “KRUTRIM’S API”, “ASSOCIATED DOCUMENTATION” AND “CODE/API USAGE EXAMPLES” AND ANY ERROR CORRECTIONS, UPDATES OR NEW RELEASES THERETO AS PROVIDED BY KRUTRIM) FOR THE INTENDED PURPOSE OF ALLOWING NETWORK ADMINISTRATORS AND DEVELOPERS (ALSO REPRESENTED AS “YOU” AND “YOUR”) TO UTILIZE THE SDK TO DEVELOP APPLICATIONS WHICH (I) ALLOW ADMINISTRATORS TO BETTER INTEGRATE KRUTRIM’S PRODUCTS INTO THEIR INTERNAL NETWORKS; AND (II) ALLOW DEVELOPERS TO EFFECTIVELY INCORPORATE KRUTRIM PRODUCTS INTO THEIR COMPANY’S BUNDLED PRODUCT OFFERINGS (“YOUR PRODUCTS”).  
THE LICENSE GRANTED BELOW GOVERNS YOUR USE OF THE SDK. THESE TERMS CONSTITUTE A LEGAL AGREEMENT BETWEEN YOU AND KRUTRIM SI DESIGNS PRIVATE LIMITED (HEREIN REFERRED TO AS “KRUTRIM”). PLEASE READ THIS SDK END USER LICENSE AGREEMENT (THE “AGREEMENT”) CAREFULLY BEFORE PRESSING THE "I AGREE" BUTTON. BY PRESSING "I AGREE," YOU ARE AGREEING TO BE BOUND BY THE TERMS OF THIS AGREEMENT. IF YOU REPRESENT A LEGAL ENTITY, YOU ACKNOWLEDGE THAT YOU HAVE THE LEGAL AUTHORITY TO BIND SUCH ENTITY. IF YOU DO NOT AGREE TO THE TERMS OF THIS AGREEMENT, DO NOT DOWNLOAD AND USE THE SDK. PRESS "CANCEL" AND EXIT THIS PART OF THE SITE.  
THERE MAY BE ADDITIONAL TERMS AND CONDITIONS APPLICABLE TO CERTAIN COMPONENTS OF THE SDK, ALL OF WHICH ARE INCORPORATED HEREIN BY REFERENCE. YOU AGREE TO ABIDE BY SUCH OTHER TERMS AND CONDITIONS. TO THE EXTENT THAT A CONFLICT EXISTS BETWEEN THE TERMS PROVIDED BELOW AND THOSE POSTED FOR OR APPLICABLE TO CERTAIN COMPONENTS OF THE SDK, THE LATTER ARE CONTROLLING.

1. **License to Use SDK: Restrictions.**  
   1. Subject to the terms and conditions of this Agreement, KRUTRIM grants you a limited, non-exclusive, non-transferable, royalty free, revocable license to use KRUTRIM’s API and the Code/API usage examples in accordance with the Associated Documentation and for the intended purpose stated above.  
   2. You may make a reasonable number of copies of any Component so as to use the SDK for the intended purpose stated above.  
   3. You may not distribute, sell, lease, lend or sublicense the SDK or any Component as an independent product.  
   4. You may not modify, create derivative works, reverse engineer, reverse compile, or disassemble KRUTRIM’s API or the Code/API usage examples in any way other than for the intended purpose stated above. You also agree not to add or delete any program files that would modify the functionality and/or appearance of KRUTRIM’s API or the Code/API usage examples other than for the intended purposes stated above.  
   5. You will not use the SDK to run applications developed by a third party or that access data, content or resources provided by a third party.  
   6. You will not use KRUTRIM’s API or the Code/API usage examples with or to (i) develop any application or program containing viruses or code that is intended to damage or detrimentally interfere with or surreptitiously intercept or expropriate any system, data or information; (ii) that violates any law or regulation; or (iii) that interferes with the operation of any KRUTRIM Product.  
   7. You may not modify, distribute or convey KRUTRIM’s API or any code contained therein so that such API, code or any application to which it links, or which it is a part of, becomes subject to an Excluded License. An Excluded License is defined as one that requires, as a condition of license, use, modification, distribution or conveyance, that (i) the code be disclosed or distributed in source code form; (ii) others have the right to modify or create derivative works of it; or (iii) it becomes redistributable at no charge.  
   8. You understand that code provided by KRUTRIM, to include the third party technologies provided, may have their own licenses or terms of use, which may or may not be made available, but which you are subject to should you use such SDK.  
2. **Intellectual Property Rights.**  
   1. You understand and agree that KRUTRIM retain all legal rights, title and interest (to include but not limited to patent, copyright, trademark, trade secret and moral rights) globally to any intellectual property included in the SDK. All rights are reserved. Accordingly, You agree not to assert any intellectual property rights related to the SDK against KRUTRIM or its suppliers.  
   2. You are expressly prohibited from using the KRUTRIM trademark and trade name and KRUTRIM Product names in any way and anywhere (to include but not limited to use in Your business’s trade names or business names, domain names, or product names) without prior authorization from KRUTRIM.  
   3. You must include KRUTRIM copyright and other proprietary rights notices accompanying Your Products.  
   4. KRUTRIM may, at its sole discretion and without restriction, use any feedback, suggestions and ideas (“Feedback”) You provide in future modifications of the SDK. You hereby grant KRUTRIM a perpetual, worldwide, fully transferable, irrevocable, royalty free license to use, reproduce, modify, create derivative works from, distribute and display the Feedback in any manner and for any purpose.  
3. **Confidentiality.**  
   You agree that the SDK is confidential and proprietary information of KRUTRIM ("Confidential Information"). As part of Your activities associated with this Agreement, You may provide Confidential Information to KRUTRIM. Confidential Information does not include information (i) that is or becomes public knowledge or is received by either party without any breach of any confidentiality obligation; (ii) that the receiving party can document was independently developed without use or access to the Confidential Information; or (iii) that the receiving party can document was previously known prior to receipt of the Confidential Information. Both parties agree to (i) use the Confidential Information only in connection with fulfilling their rights and obligations under this Agreement; (ii) hold the Confidential Information in strict confidence and exercise due care with respect to its handling and protection, consistent with their protection of their own confidential information but not less than reasonable care, (iii) not publish or disclose the Confidential Information except for disclosures to employees and subcontractors who have a bona fide need to know the Confidential Information. Both parties agree that any unauthorized disclosure of the Confidential Information would cause irreparable harm and that in the event of any breach or threatened breach of the above confidentiality obligations, the party owning the Confidential Information shall be entitled to obtain equitable relief in addition to any other remedy.  
4. **No KRUTRIM Support or Software Maintenance.**  
   KRUTRIM may but is under no obligation to provide updates, fix bugs or errors nor to address any other issues you may raise with the quality or performance of any component of the SDK.  
5. **Termination.**  
   Your rights under this Agreement may be terminated by KRUTRIM immediately and without notice if You fail to comply with any term or condition of this Agreement. Upon such termination, Your license to the SDK will terminate immediately and You must immediately cease using the SDK, and destroy all complete and partial copies of the SDK within Your possession or control. You and or KRUTRIM each may terminate this Agreement for any reason at any time with a minimum of ninety (90) days notice.  
6. **Warranty Disclaimer.**  
   KRUTRIM DISCLAIMS ALL REPRESENTATIONS OR WARRANTIES OF ANY KIND, EITHER EXPRESS OR IMPLIED, REGARDING THE USE OF THE SDK, TO INCLUDE BUT NOT LIMITED TO WARRANTIES OF TITLE, MERCHANTIBILITY, FITNESS FOR A PARTICULAR PURPOSE, OR NONINFRINGEMENT OR WARRANTIES THAT THE SDK WILL BE ACCURATE, FREE OF ERRORS OR DEFECTS, FREE OF VIRUSES OR CONTAMINATION, UNINTERRUPTED, OR THAT ANY DEFECTS WILL BE CORRECTED. THE SDK IS PROVIDED “AS-IS”. YOU ASSUME ALL RISK ASSOCIATED WITH YOUR USE OF THE SDK. YOUR SOLE REMEDY AGAINST KRUTRIM FOR DISSATISFACTION WITH THE SDK OR FOR ANY DAMAGE CAUSED THEREBY IS TO STOP USING SUCH SDK. THIS LIMITATION OF RELIEF IS A PART OF THE BARGAIN BETWEEN THE PARTIES.  
7. **Limitation of Liability.**  
   1. YOU AGREE NOT TO TAKE ANY LEGAL ACTION OR MAKE ANY CLAIM AGAINST KRUTRIM OR ANY OF ITS SUPPLIERS IN RELATION TO THE SDK AND/OR YOUR USAGE THEREOF. FURTHERMORE YOU AGREE NOT TO SUPPORT ANY SUCH ACTIONS OR CLAIMS BY ANY OF YOUR CUSTOMERS WHO MAY RECEIVE THE SDK OR COMPONENTS THEREOF AS PART OF YOUR PRODUCTS.  
   2. YOU ACKNOWLEDGE AND AGREE THAT ANY USE OR DISSEMINATION BY YOU OF THE SDK IS YOUR SOLE RESPONSIBILITY AND AT YOUR OWN RISK. YOU ACKNOWLEDGE AND AGREE THAT KRUTRIM BEARS NO LIABILITY OR RESPONSIBILITY FOR SUCH USE OR DISSEMINATION. AS SUCH, EXCEPT WHERE PROHIBITED BY LAW, IN NO EVENT WILL KRUTRIM BE LIABLE TO YOU FOR ANY DAMAGES OF ANY KIND, UNDER ANY LEGAL THEORY, TO INCLUDE DIRECT, INDIRECT, CONSEQUENTIAL, SPECIAL, EXEMPLARY, INCIDENTAL OR PUNITIVE DAMAGES, WHETHER RELATED TO BUSINESS INTERRUPTION/WORK STOPPAGE, LOST PROFITS, LOSS OF DATA, COMPUTER MALFUNCTION OR FAILURE OR OTHERWISE. EVEN IF KRUTRIM HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. IF, NOTWITHSTANDING THE OTHER PROVISIONS OF THIS AGREEMENT, KRUTRIM IS FOUND TO BE LIABLE TO YOU FOR ANY DAMAGE OR LOSS THAT ARISES OUT OF OR IS IN ANY WAY CONNECTED WITH YOUR USE OF THE SDK, KRUTRIM’S LIABILITY SHALL BE LIMITED TO THE GREATEST EXTENT ALLOWED BY THE LAW.  
8. **Indemnification.**  
   YOU AGREE TO FULLY INDEMNIFY AND HOLD HARMLESS KRUTRIM, ITS DIRECTORS, OFFICERS AND EMPLOYEES, AGAINST ANY AND ALL CLAIMS, TO INCLUDE ATTORNEYS” FEES, MADE REGARDING (I) YOUR USE OF THE SDK, (II) ANY APPLICATION YOU DEVELOP THEREFROM, (III) ANY INTELLECTUAL PROPERTY INFRINGEMENT CLAIM THAT ARISES FROM YOUR USE OF THE SDK AND ANY APPLICATION DEVELOPED THEREFROM, AND/OR (IV) YOUR BREACH OF THIS AGREEMENT.  
9. **Notices.**  
   KRUTRIM may send You notice with respect to this Agreement by sending an email message to the email address listed in Your Developer Portal account or by sending a letter via postal mail to the contact address listed in Your account. Notices shall become effective immediately upon KRUTRIM providing them.  
10. **Governing Law.**

All disputes or differences arising shall at the first instance be attempted to be resolved amicably between the Parties by negotiation within 30 (Thirty) days from the receipt of notice of such dispute. On the failure of negotiation, the dispute in connection with this Agreement, including any question regarding its existence, validity or termination, shall be referred to and resolved by arbitration in Bengaluru in accordance with the Indian Arbitration and Conciliation Act, 1996\. The arbitration shall be presided over by a sole arbitrator appointed mutually by the Parties. The language of arbitration shall be English. The order passed by the arbitrator shall be final and binding upon the Parties.The parties hereby acknowledge that the language of this Agreement is English and that the original English-language version of this Agreement shall be the only authoritative version of this Agreement.

11. **Miscellaneous.**  
    1. No delay or failure to take action under this Agreement will constitute a waiver unless expressly waived in writing, signed by a duly authorized KRUTRIM representative, and no single waiver will constitute a continuing or subsequent waiver.  
    2. If any provision is found to be unenforceable or invalid, that provision shall be limited or eliminated to the minimum extent necessary so that this Agreement shall otherwise remain in full force and effect and enforceable.  
    3. This Agreement constitutes the entire agreement between the parties with respect to Your use of the SDK.  
12. **Changes to this Agreement.**  
    1. KRUTRIM shall have the right to unilaterally change or add to the terms of this Agreement at any time upon notice by any means KRUTRIM determines in its discretion to be reasonable, including sending you an email notification, by KRUTRIM Channel Alert publication or by simply referencing a posted, newly revised version of the Agreement on its Developer Zone Portal website. It is Your responsibility to review the most updated version thereof. By continuing to use the SDK following such modifications, You agree to be bound by such modifications.  
    2. The Confidential Information, Warranty Disclaimer, Limitation of Liability and Indemnification sections set out in this Agreement shall survive any termination or expiration of this Agreement.

